#!/usr/bin/env node
'use strict';

const program = require('commander'),
    packConf = require('../package.json'),
    spawn = require('cross-spawn'),
    path = require('path'),
    fs = require('fs-extra'),
    chalk = require('chalk');

function wrap(sp) {
  sp.on('close', function(code) {
    process.exit(code);
  });
}

function executable(subcmd) {
  var file = path.join(__dirname, subcmd+'.js');
  if (fs.existsSync(file)) {
    return file;
  }
}

program
  .version(packConf.version)
//   .option('-C, --chdir <path>', 'change the working directory')
//   .option('-c, --config <path>', 'set config path. defaults to ./deploy.conf')
//   .option('-T, --no-tests', 'ignore test hook')


program
    .command('new')
    .description('构建项目工程')
    .usage('<project name>')
    .action(function (cmd) {
        console.log(chalk.green('peak: build project.'));
        /**
         * 判断是否存在文件
         * 是 -> 提示
         * 否 -> 执行命令
         */
        if(fs.existsSync(cmd)){
            console.log(chalk.red('peak: project name is exist!'));
            process.exit(1);
        }else{
            console.log(chalk.green('peak: executing command (new...).'));
            const args = process.argv.slice(3);
            // const subcmd = program.args[0];
            const runPath = executable(process.argv.slice(2,3));
            wrap(spawn(runPath, args, {stdio: 'inherit', customFds: [0, 1, 2]}));
        }
    }).on('--help', function() {
    console.log('  Examples:');
    console.log();
    console.log('    $ peak new react-demo');
    console.log();
  });

  program
  .command('update')
  .description('升级项目的相关配置文件(/bin/*、/config/*、/peak.json)')
  .usage('<project name>')
  .action(function (cmd) {
      console.log(chalk.green('peak: update project.'));
      /**
       * 判断是否存在文件
       * 是 -> 提示
       * 否 -> 执行命令
       */
      if(fs.existsSync(cmd)){
          console.log(chalk.red('peak: project name is exist!'));
          process.exit(1);
      }else{
          console.log(chalk.green('peak: executing command (update).'));
          const args = process.argv.slice(3);
          const runPath = executable(process.argv.slice(2,3));
          wrap(spawn(runPath, args, {stdio: 'inherit', customFds: [0, 1, 2]}));
      }
  }).on('--help', function() {
  console.log('  Examples:');
  console.log();
  console.log('    $ peak new react-demo');
  console.log();
});

  program
    .command('doc')
    .description('相关技术文档')
    .usage('<doc name>')
    .action(function (cmd) {
        console.log(chalk.green('peak: find document.'));
        if(fs.existsSync(cmd)){
            console.log(chalk.red('peak: project name is exist!'));
        }else{
            console.log(chalk.green('peak: executing command (new...)'));
            const args = process.argv.slice(3);
            // const subcmd = program.args[0]
            const runPath = executable(process.argv.slice(2,3));
            wrap(spawn(runPath, args, {stdio: 'inherit', customFds: [0, 1, 2]}));
        }
    }).on('--help', function() {
    console.log('  Examples:');
    console.log();
    console.log('    $ peak doc ---> return 所有可选择文档目录');
    console.log('    $ peak doc react ---> return react相关技术文档目录');
    console.log();
  });

  program
      .command('*')
      .description('无此命令')
      .action(function(cmd){
          console.log('peak: deploying "%s"', cmd);
      });

program.parse(process.argv);
